@@ -226,7 +226,7 @@ glxConvertConfigs(const __DRIcoreExtension * core,
     }
 
     for (i = 0; configs[i]; i++) {
-        int renderType = 0;
+        unsigned int renderType = 0;
         if (core->getConfigAttrib(configs[i], __DRI_ATTRIB_RENDER_TYPE,
                                   &renderType)) {
             if (render_type_is_pbuffer_only(renderType) &&
