@@ -47,6 +47,7 @@
 #include <scrnintstr.h>
 
 #include <GL/gl.h>
+#include <GL/glext.h>
 #include <GL/glxproto.h>
 
 /*
@@ -97,7 +98,7 @@ struct __GLXprovider {
     const char *name;
     __GLXprovider *next;
 };
-__GLXprovider __glXDRISWRastProvider;
+extern __GLXprovider __glXDRISWRastProvider;
 
 void GlxPushProvider(__GLXprovider * provider);
 
@@ -115,6 +116,20 @@ void __glXleaveServer(GLboolean rendering);
 void glxSuspendClients(void);
 void glxResumeClients(void);
 
+typedef void (*glx_func_ptr)(void);
+typedef glx_func_ptr (*glx_gpa_proc)(const char *);
+void __glXsetGetProcAddress(glx_gpa_proc get_proc_address);
+void *__glGetProcAddress(const char *);
+
+void
+__glXsendSwapEvent(__GLXdrawable *drawable, int type, CARD64 ust,
+                   CARD64 msc, CARD32 sbc);
+
+#if PRESENT
+void
+__glXregisterPresentCompleteNotify(void);
+#endif
+
 /*
 ** State kept per client.
 */
